
// Execute the following code when the page is fully loaded
window.onload = function() {
  // Select the "Circles" pattern type by default
  const patternTypeSelect = document.getElementById("pattern-type");
  patternTypeSelect.value = "circles";
  
  // Generate a random pattern color and background color
  const patternColorInput = document.getElementById("pattern-color");
  const backgroundColorInput = document.getElementById("background-color");
  
  patternColorInput.value = generateRandomColor();
  backgroundColorInput.value = generateRandomColor();
  
  // Generate the pattern based on the default selection
  generatePattern();
};

function handlePatternTypeChange() {
  const patternType = document.getElementById("pattern-type").value;
  const rotationControl = document.getElementById("rotation-control");
  rotationControl.style.display = patternType === "grid" ? "none" : "block";
  generatePattern();
}

function generatePattern() {
  var patternType = document.getElementById("pattern-type").value;
  var opacity = document.getElementById("opacity").value;
  var spacing = document.getElementById("spacing").value;
  var rotate = document.getElementById("rotate").value;
  var patternBox = document.getElementById("pattern-box");
  var cssCode = document.getElementById("css-code");

  var patternColor = document.getElementById("pattern-color").value;
  var backgroundColor = document.getElementById("background-color").value;

  if (patternType === "stripes") {
    patternBox.style.background = `linear-gradient(${rotate}deg, ${patternColor} ${spacing}px, ${backgroundColor} ${spacing}px)`;
    cssCode.innerText = `background: linear-gradient(${rotate}deg, ${patternColor} ${spacing}px, ${backgroundColor} ${spacing}px); opacity: ${opacity};`;
    
  } else if (patternType === "dots") {
    patternBox.style.background = `radial-gradient(circle at center, ${patternColor} 10%, ${backgroundColor} 10.1%)`;
    cssCode.innerText = `background: radial-gradient(circle at center, ${patternColor} 10%, ${backgroundColor} 10.1%); opacity: ${opacity};`;
    
  } else if (patternType === "grid") {
    patternBox.style.background = `repeating-linear-gradient(${rotate}deg, ${patternColor}, ${patternColor} ${spacing}px, ${backgroundColor} ${spacing}px, ${backgroundColor} ${2 * spacing}px)`;
    cssCode.innerText = `background: repeating-linear-gradient(${rotate}deg, ${patternColor}, ${patternColor} ${spacing}px, ${backgroundColor} ${spacing}px, ${backgroundColor} ${2 * spacing}px); opacity: ${opacity};`;
    
  } else if (patternType === "bars") {
    patternBox.style.background = `linear-gradient(135deg, ${patternColor} 20.5%, ${backgroundColor} 0 29.5%, ${patternColor} 0) 0 ${spacing}px, linear-gradient(45deg, ${patternColor} 8%, ${backgroundColor} 0 17%, ${patternColor} 0 58%) ${spacing * 2}px 0, linear-gradient(135deg, ${patternColor} 8%, ${backgroundColor} 0 17%, ${patternColor} 0 58%, ${backgroundColor} 0 67%, ${patternColor} 0), linear-gradient(45deg, ${patternColor} 8%, ${backgroundColor} 0 17%, ${patternColor} 0 58%, ${backgroundColor} 0 67%, ${patternColor} 0 83%, ${backgroundColor} 0 92%, ${patternColor} 0), ${backgroundColor}`;
    patternBox.style.backgroundSize = `40px 40px`;
    cssCode.innerText = `background: linear-gradient(135deg, ${patternColor} 20.5%, ${backgroundColor} 0 29.5%, ${patternColor} 0) 0 ${spacing}px, linear-gradient(45deg, ${patternColor} 8%, ${backgroundColor} 0 17%, ${patternColor} 0 58%) ${spacing * 2}px 0, linear-gradient(135deg, ${patternColor} 8%, ${backgroundColor} 0 17%, ${patternColor} 0 58%, ${backgroundColor} 0 67%, ${patternColor} 0), linear-gradient(45deg, ${patternColor} 8%, ${backgroundColor} 0 17%, ${patternColor} 0 58%, ${backgroundColor} 0 67%, ${patternColor} 0 83%, ${backgroundColor} 0 92%, ${patternColor} 0), ${backgroundColor}; background-size: 40px 40px; opacity: ${opacity};`;
    
  } else if (patternType === "isometric") {
    patternBox.style.background = `linear-gradient(30deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(150deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(30deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(150deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(60deg, ${patternColor}77 25%, transparent 25.5%, transparent 75%, ${patternColor}77 75%, ${patternColor}77), linear-gradient(60deg, ${patternColor}77 25%, transparent 25.5%, transparent 75%, ${patternColor}77 75%, ${patternColor}77)`;
    patternBox.style.backgroundSize = `38px 67px`;
    patternBox.style.backgroundPosition = `0 0, 0 0, ${spacing}px ${spacing / 2}px, ${spacing}px ${spacing / 2}px, 0 0, ${spacing}px ${spacing / 2}px`;
    cssCode.innerText = `background-color: ${backgroundColor}; opacity: ${opacity}; background-image: linear-gradient(30deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(150deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(30deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(150deg, ${patternColor} 12%, transparent 12.5%, transparent 87%, ${patternColor} 87.5%, ${patternColor}), linear-gradient(60deg, ${patternColor}77 25%, transparent 25.5%, transparent 75%, ${patternColor}77 75%, ${patternColor}77), linear-gradient(60deg, ${patternColor}77 25%, transparent 25.5%, transparent 75%, ${patternColor}77 75%, ${patternColor}77); background-size: 38px 67px; background-position: 0 0, 0 0, ${spacing}px ${spacing / 2}px, ${spacing}px ${spacing / 2}px, 0 0, ${spacing}px ${spacing / 2}px;`;
    
  } else if (patternType === "wavy") {
    patternBox.style.background = `repeating-radial-gradient(circle at 0 0, transparent 0, ${backgroundColor} ${spacing}px), repeating-linear-gradient(${patternColor}55, ${patternColor})`;
    cssCode.innerText = `background-color: ${backgroundColor}; opacity: ${opacity}; background-image: repeating-radial-gradient(circle at 0 0, transparent 0, ${backgroundColor} ${spacing}px), repeating-linear-gradient(${patternColor}55, ${patternColor});`;
    
  } else if (patternType === "zigzag3d") {
    patternBox.style.background = `linear-gradient(135deg, ${patternColor} 25%, transparent 25%) -${spacing}px 0/${spacing * 2}px ${spacing * 2}px, linear-gradient(225deg, ${patternColor} 25%, transparent 25%) -${spacing}px 0/${spacing * 2}px ${spacing * 2}px, linear-gradient(315deg, ${patternColor} 25%, transparent 25%) 0 0/${spacing * 2}px ${spacing * 2}px, linear-gradient(45deg, ${patternColor} 25%, ${backgroundColor} 25%) 0 0/${spacing * 2}px ${spacing * 2}px`;
    cssCode.innerText = `background-color: ${backgroundColor}; opacity: ${opacity}; background: linear-gradient(135deg, ${patternColor} 25%, transparent 25%) -${spacing}px 0/${spacing * 2}px ${spacing * 2}px, linear-gradient(225deg, ${patternColor} 25%, transparent 25%) -${spacing}px 0/${spacing * 2}px ${spacing * 2}px, linear-gradient(315deg, ${patternColor} 25%, transparent 25%) 0 0/${spacing * 2}px ${spacing * 2}px, linear-gradient(45deg, ${patternColor} 25%, ${backgroundColor} 25%) 0 0/${spacing * 2}px ${spacing * 2}px;`;
    
  } else if (patternType === "circles") {
    patternBox.style.background = `radial-gradient(circle at center center, ${patternColor}, ${backgroundColor}), repeating-radial-gradient(circle at center center, ${patternColor}, ${patternColor} ${spacing}px, transparent ${spacing * 2}px, transparent ${spacing}px)`;
    patternBox.style.backgroundBlendMode = `multiply`;
    cssCode.innerText = `background-color: ${backgroundColor}; opacity: ${opacity}; background-image: radial-gradient(circle at center center, ${patternColor}, ${backgroundColor}), repeating-radial-gradient(circle at center center, ${patternColor}, ${patternColor} ${spacing}px, transparent ${spacing * 2}px, transparent ${spacing}px); background-blend-mode: multiply;`;
    
  } else if (patternType === "triangle") {
    patternBox.style.background = `linear-gradient(45deg, ${patternColor} 50%, ${backgroundColor} 50%)`;
    patternBox.style.backgroundSize = `${spacing}px ${spacing}px`;
    cssCode.innerText = `background-color: ${backgroundColor}; opacity: ${opacity}; background-image: linear-gradient(45deg, ${patternColor} 50%, ${backgroundColor} 50%); background-size: ${spacing}px ${spacing}px;`;
    
  } else if (patternType === "rectangle") {
    patternBox.style.background = `repeating-linear-gradient(45deg, ${patternColor} 25%, transparent 25%, transparent 75%, ${patternColor} 75%, ${patternColor}), repeating-linear-gradient(45deg, ${patternColor} 25%, ${backgroundColor} 25%, ${backgroundColor} 75%, ${patternColor} 75%, ${patternColor})`;
    patternBox.style.backgroundPosition = `0 0, ${spacing}px ${spacing}px`;
    patternBox.style.backgroundSize = `${spacing * 2}px ${spacing * 2}px`;
    cssCode.innerText = `background-color: ${backgroundColor}; opacity: ${opacity}; background-image: repeating-linear-gradient(45deg, ${patternColor} 25%, transparent 25%, transparent 75%, ${patternColor} 75%, ${patternColor}), repeating-linear-gradient(45deg, ${patternColor} 25%, ${backgroundColor} 25%, ${backgroundColor} 75%, ${patternColor} 75%, ${patternColor}); background-position: 0 0, ${spacing}px ${spacing}px; background-size: ${spacing * 2}px ${spacing * 2}px;`;
    
  }

  patternBox.style.opacity = opacity;
}

function shuffleColors() {
  var patternColor = document.getElementById("pattern-color");
  var backgroundColor = document.getElementById("background-color");

  // Generate random color values
  var randomPatternColor = generateRandomColor();
  var randomBackgroundColor = generateRandomColor();

  // Set the random color values to the input fields
  patternColor.value = randomPatternColor;
  backgroundColor.value = randomBackgroundColor;

  // Trigger the pattern generation with the shuffled colors
  generatePattern();
}

function generateRandomColor() {
  // Generate a random hexadecimal color code
  return "#" + Math.floor(Math.random() * 16777215).toString(16);
}

function handlePatternTypeChange() {
    const patternType = document.getElementById("pattern-type").value;
    const rotationControl = document.getElementById("rotation-control");
    rotationControl.style.display = patternType === "grid" ? "block" : "none";
    generatePattern();
  }
function copyCSSCode() {
  const cssCode = document.getElementById("css-code");
  const code = cssCode.innerText;

  navigator.clipboard.writeText(code).then(() => {
    alert("CSS code copied to clipboard!");
  });
}
